@@ -62,6 +62,7 @@ class GCPInstance(VMInterface):
         ngpus=None,
         gpu_type=None,
         bootstrap=None,
+        extra_bootstrap=None,
         gpu_instance=None,
         auto_shutdown=None,
         preemptible=False,
@@ -94,6 +95,7 @@ class GCPInstance(VMInterface):
         self.gpu_type = gpu_type or self.config.get("gpu_type")
         self.gpu_instance = gpu_instance
         self.bootstrap = bootstrap
+        self.extra_bootstrap = extra_bootstrap
         self.auto_shutdown = auto_shutdown
         self.preemptible = preemptible
 
@@ -306,18 +308,19 @@ class GCPScheduler(SchedulerMixin, GCPInstance):
             # scheduler must be publicly available, and firewall
             # needs to be in place to allow access to 8786 on
             # the external IP
-            self.address = f"{self.cluster.protocol}://{self.external_ip}:8786"
+            self.address = f"{self.cluster.protocol}://{self.external_ip}:{self.port}"
         else:
             # if the client is running inside GCE environment
             # it's better to use internal IP, which doesn't
             # require firewall setup
-            self.address = f"{self.cluster.protocol}://{self.internal_ip}:8786"
+            self.address = f"{self.cluster.protocol}://{self.internal_ip}:{self.port}"
         await self.wait_for_scheduler()
 
         # need to reserve internal IP for workers
         # gcp docker containers can't see resolve ip address
         self.cluster.scheduler_internal_ip = self.internal_ip
         self.cluster.scheduler_external_ip = self.external_ip
+        self.cluster.scheduler_port = self.port
 
 
 class GCPWorker(GCPInstance):
@@ -335,9 +338,12 @@ class GCPWorker(GCPInstance):
         self.scheduler = scheduler
         self.worker_class = worker_class
         self.name = f"dask-{self.cluster.uuid}-worker-{str(uuid.uuid4())[:8]}"
-        internal_scheduler = (
-            f"{self.cluster.protocol}://{self.cluster.scheduler_internal_ip}:8786"
+        proto, ip, port = (
+            self.cluster.protocol,
+            self.cluster.scheduler_internal_ip,
+            self.cluster.scheduler_port,
         )
+        internal_scheduler = f"{proto}://{ip}:{port}"
         self.command = " ".join(
             [
                 self.set_env,
@@ -613,6 +619,9 @@ class GCPCluster(VMCluster):
         self.scheduler_options = {**self.options}
         self.worker_options = {**self.options}
 
+        if "extra_bootstrap" not in kwargs:
+            kwargs["extra_bootstrap"] = self.config.get("extra_bootstrap")
+
         super().__init__(debug=debug, **kwargs)
 
 
